OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Solecitare nereușită, conexiune la rețeă indisponibilă!",
    "Request unauthorized. Are you logged in?" : "Cerere neautorizată. Ești autentificat ?",
    "Request forbidden. Are you an admin?" : "Cerere interzisă. Ești un administrator ?",
    "Token expired or app not enabled! Reload the page!" : "Token expirat sau aplicatie inactivă. Reîncarcă pagina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Eroare server internă! Controlați fișierul data/nextcloud.log pentru mai multe informații!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Solecitare nereușită, Nexcloud este în întreţinere!",
    "Can not add feed: Exists already" : "Nu pot adăuga fluxul: Deja există!",
    "Articles without feed" : "Articole fără flux",
    "Can not add folder: Exists already" : "Nu se poate adăuga directorul : Există deja",
    "News" : "Noutăți",
    "Saved" : "Salvat",
    "Download" : "Descarcă",
    "Close" : "Închide",
    "filter" : "filtru",
    "Language" : "Limbă",
    "Subscribe" : "Abonare",
    "No articles available" : "Niciun articol disponibil",
    "No unread articles available" : "Niciun articol necitit disponibil",
    "Open website" : "Deschide website",
    "Keep article unread" : "Păstrează articolul necitit",
    "by" : "de",
    "from" : "de la",
    "Description" : "Descriere",
    "right" : "dreapta",
    "left" : "stânga",
    "Refresh" : "Împrospătare",
    "Web address" : "Adresă web",
    "Feed exists already!" : "Fluxul există deja!",
    "Folder" : "Director",
    "No folder" : "Niciun director",
    "New folder" : "Director nou",
    "Folder name" : "Denumire director",
    "Go back" : "Înapoi",
    "Folder exists already!" : "Directorul există deja!",
    "Credentials" : "Detalii de autentificare",
    "Username" : "Utilizator",
    "Password" : "Parolă",
    "New Folder" : "Director nou",
    "Create" : "Crează",
    "Explore" : "Explorează",
    "Update failed more than 50 times" : "Actualizarea a eșuat mai mult de 50 de ori",
    "Deleted feed" : "Flux șters",
    "Undo delete feed" : "Anulează ștergerea fluxului",
    "Rename" : "Redenumește",
    "Menu" : "Meniu",
    "Newest first" : "Cel mai nou mai întâi",
    "Oldest first" : "Cel mai vechi mai întâi",
    "Delete" : "Șterge",
    "Dismiss" : "Înlătură",
    "Collapse" : "Restrânge",
    "Deleted folder" : "Director șters",
    "Undo delete folder" : "Anulează ștergerea directorului",
    "Starred" : "Marcat",
    "Unread articles" : "Articole necitite",
    "All articles" : "Toate articolele",
    "Settings" : "Setări",
    "Compact view" : "Vizualizare compactă",
    "Show all articles" : "Arată toate articolele",
    "Subscriptions (OPML)" : "Subscripţii (OPLM)",
    "Import" : "Importă",
    "Export" : "Exportă",
    "Error when importing: file does not contain valid JSON" : "Eroare în timpul importării : fişierul nu conţine  JSON valid",
    "Help" : "Ajutor",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Documentation" : "Documentație",
    "Report a bug" : "Raportează un defect"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
